@@ -208,6 +208,32 @@ class WordPressManager {
             error_log("Warning: Failed to install wp-cli-login-command: " . $loginResult['output']);
         }
         
+        // Install and activate default theme (WordPress core install doesn't include themes)
+        $themeCmd = "wp theme install twentytwentyfour --activate";
+        $themeResult = $this->execWpCli($data['container'], $data['user'], $themeCmd, $path);
+        if (!$themeResult['success']) {
+            // Try an older theme if the latest fails
+            $themeCmd = "wp theme install twentytwentythree --activate";
+            $themeResult = $this->execWpCli($data['container'], $data['user'], $themeCmd, $path);
+            if (!$themeResult['success']) {
+                error_log("Warning: Failed to install default theme: " . $themeResult['output']);
+            }
+        }
+        
+        // Set up proper permalink structure with .htaccess
+        $permalinkCmd = "wp rewrite structure '/%postname%/'";
+        $permalinkResult = $this->execWpCli($data['container'], $data['user'], $permalinkCmd, $path);
+        if (!$permalinkResult['success']) {
+            error_log("Warning: Failed to set up permalinks: " . $permalinkResult['output']);
+        }
+        
+        // Flush rewrite rules to ensure .htaccess is created
+        $flushCmd = "wp rewrite flush --hard";
+        $flushResult = $this->execWpCli($data['container'], $data['user'], $flushCmd, $path);
+        if (!$flushResult['success']) {
+            error_log("Warning: Failed to flush rewrite rules: " . $flushResult['output']);
+        }
+        
         // Save site information to database
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
@@ -734,7 +760,7 @@ Options -Indexes
         }
         
         // First, ensure the wp-cli-login-command plugin is installed and activated
-        $installCmd = "wp login install --activate";
+        $installCmd = "wp login install --activate --mu --yes";
         $installResult = $this->execWpCli($site['container_name'], $site['user'], $installCmd, $path);
         
         // If installation fails, try to continue anyway (plugin might already be installed)
